<?php

	/*

		Single File PHP Audio Player 2.0.0

		See END USER LICENSE AGREEMENT for commercial use

		Released: 25-Feb-2025
		https://sye.dk/sfpap/
		By Kenny Svalgaard

	*/

	// --------------------- CONFIGURATION ----------------------

	define('CHARSET', 'UTF-8');
	define('SERVER_TIMEOUT', 15);
	define('MIN_SEARCH_STR', 1);
	define('MAX_SEARCH_RESULT', 100);
	define('TRACK_AS_TITLE', true);
	define('ERROR_NEXT_SEC', 5);
	define('AUDIO_EXTENSIONS', ['mp3','wav','ogg']);
	define('SKIP_BUTTONS_MENU', [5, 10, 30, 60, -5, -10, -30, -60]);
	define('SKIP_BUTTONS_LANDSCAPE', [5, 10, 30, 60, -5, -10, -30, -60]);
	define('DIR_EXCLUDE_ARR', []);  // Use only lower case.
	define('DIR_EXCLUDE_REGEX', '');

	define('TXT_PLAYER_TITLE', 'sfPAP');
	define('TXT_ROOT', 'Home');
	define('TXT_BROWSER', 'Browse');
	define('TXT_PLAYLIST', 'Playlist');
	define('TXT_SEARCH', 'Search');
	define('TXT_TRACKS', 'Titles in playlist');
	define('TXT_CLEAR', '- Click to clear');
	define('TXT_EMPTY', 'Playlist is Empty');
	define('TXT_TITLE', 'Title');
	define('TXT_DIR', 'Directory');
	define('TXT_THEME', 'Theme - Toggle between Follow device, Light and Dark theme.');
	define('TXT_SHUFFLE', 'Shuffle - Play tracks in random order.');
	define('TXT_LOOP', 'Loop - Repeat playback continuously.');
	define('TXT_TREE', 'Tree - When playing from browser, continue playing next directory.');
	define('TXT_ACC_DIR', 'Server is unable to access directory');
	define('TXT_NO_RES', 'Server not responding');
	define('TXT_SEARCH_RES', 'search result');
	define('TXT_SEARCHING', 'Searching...');
	define('TXT_SEARCH_DESC', 'Type and choose Title or Directory');
	define('TXT_TOO_MANY', 'Too many matches. Result have been limited to ');
	define('TXT_MIN_SEARCH', 'Minimum search characters: ');
	define('TXT_TRACK_ERROR', "Unable to access or play track. Playing next track in '+time+' seconds");
	define('TXT_EXIT', 'Quit player?');

	// Light mode colors
	define('CLR_LIGHT_BACK', '#dddddd');
	define('CLR_LIGHT_TEXT', '#000000');
	define('CLR_LIGHT_TEXT_SMALL', '#555555');
	define('CLR_LIGHT_TAB', '#aaaaaa');
	define('CLR_LIGHT_TAB_ACT', '#ffffff');
	define('CLR_LIGHT_BUTTON', '#aaaaaa');
	define('CLR_LIGHT_LED_DISABLED', '#808080');
	define('CLR_LIGHT_LED_ON', '#ffffff');
	define('CLR_LIGHT_LED_OFF', '#000000');
	define('CLR_LIGHT_TIME_BOX', '#eeeeee');
	define('CLR_LIGHT_TRACK_BOX', '#eeeeee');
	define('CLR_LIGHT_PATH', '#bbbbbb');
	define('CLR_LIGHT_DIR', '#bbbbbb');
	define('CLR_LIGHT_TRACK', '#aaaaaa');
	define('CLR_LIGHT_TRACK_HL', '#dddddd');
	define('CLR_LIGHT_SEARCH', '#dddddd');
	define('CLR_LIGHT_COLLECTION', '#cccccc');
	define('CLR_LIGHT_TEXT_ERROR', '#ff0000');
	define('CLR_LIGHT_SCROLLBAR_TRACK', '#eeeeee');
	define('CLR_LIGHT_SCROLLBAR_THUMB', '#aaaaaa');

	// Dark mode colors
	define('CLR_DARK_BACK', '#222222');
	define('CLR_DARK_TEXT', '#bbbbbb');
	define('CLR_DARK_TEXT_SMALL', '#aaaaaa');
	define('CLR_DARK_TAB', '#555555');
	define('CLR_DARK_TAB_ACT', '#000000');
	define('CLR_DARK_BUTTON', '#555555');
	define('CLR_DARK_LED_DISABLED', '#444444');
	define('CLR_DARK_LED_ON', '#bbbbbb');
	define('CLR_DARK_LED_OFF', '#000000');
	define('CLR_DARK_TIME_BOX', '#111111');
	define('CLR_DARK_TRACK_BOX', '#111111');
	define('CLR_DARK_PATH', '#444444');
	define('CLR_DARK_DIR', '#444444');
	define('CLR_DARK_TRACK', '#555555');
	define('CLR_DARK_TRACK_HL', '#222222');
	define('CLR_DARK_SEARCH', '#222222');
	define('CLR_DARK_COLLECTION', '#333333');
	define('CLR_DARK_TEXT_ERROR', '#ff0000');
	define('CLR_DARK_SCROLLBAR_TRACK', '#222222');
	define('CLR_DARK_SCROLLBAR_THUMB', '#555555');


	// ------------------ END OF CONFIGURATION ------------------


	function ea($var)
	{
		if(is_array($var))
		{
			$res='';
			foreach($var as $v)
			{
				if(is_array($v))
				{
					$res.=($res?',':'').ea($v);
				}
				else
				{
					$res.=($res?',':'').'"'.$v.'"';
				}
			}
		}
		else
		{
			$res='"'.$var.'"';
		}
		return '['.$res.']';
	}


	function is_ok_dir($dir, $item)
	{
		return (is_dir('./'.$dir.$item) and ($item!='.') and ($item!='..') and !in_array(strtolower($item), DIR_EXCLUDE_ARR) and !@preg_match(DIR_EXCLUDE_REGEX, $item));
	}


	function searchForTitle($str,$dir='')
	{
		$titles=[];
		$items=@scandir('./'.$dir);
		if ($items!==false)
		{
			foreach($items as $item)
			{
				if(is_ok_dir($dir,$item))
				{
					$titles=array_merge($titles,searchForTitle($str, $dir.$item.'/'));
				}
				elseif(isAudioFile($item) and (mb_stripos($item,$str)!==false))
				{
					$titles[]=$dir.$item;
				}
				if(count($titles)>MAX_SEARCH_RESULT)
				{
					$titles=array_slice($titles,0,MAX_SEARCH_RESULT+1);
					break;
				}
			}
		}
		return $titles;
	}


	function searchForDir($str,$dir='')
	{
		$dirs=[];
		$items=@scandir('./'.$dir);
		if ($items!==false)
		{
			foreach($items as $item)
			{
				if(is_ok_dir($dir,$item))
				{
					$dirs=array_merge($dirs,searchForDir($str, $dir.$item.'/'));
					if(mb_stripos($item,$str)!==false)
					{
						$dirs[]=$dir.$item;
					}
				}
				if(count($dirs)>MAX_SEARCH_RESULT)
				{
					$dirs=array_slice($dirs,0,MAX_SEARCH_RESULT+1);
					break;
				}
			}
		}
		return $dirs;
	}


	function isAudioFile($item)
	{
		return (array_search(mb_strtolower(mb_substr($item,mb_strrpos($item,'.')+1)),AUDIO_EXTENSIONS)!==false);
	}


	function lastDirInString($dir)
	{
		$dirArr=explode('/',trim($dir,'/'));
		return $dirArr[count($dirArr)-1];
	}


	function parentDir($dir)
	{
		$dirArr=explode('/',trim($dir,'/'));
		$parentDir='';
		for ($i=0; $i<(count($dirArr)-1); $i++) 
		{
			$parentDir.=$dirArr[$i].'/';
		}
		return $parentDir;
	}


	function getDirsAndTitles($dir)
	{
		$dirs=[];
		$titles=[];
		$items=@scandir('./'.$dir);
		if ($items!==false)
		{
			foreach($items as $item)
			{
				if(is_ok_dir($dir,$item))
				{
					$dirs[]=$item;
				}
				elseif(isAudioFile($item))
				{
					$titles[]=$item;
				}
			}
		}
		sort($dirs, SORT_FLAG_CASE | SORT_NATURAL);		
		sort($titles, SORT_FLAG_CASE | SORT_NATURAL);
		return [$dirs, $titles];
	}


	function findFirstTitleFrom($startDir, $getTracksFromStartDir, $comingFrom='')
	{
		// get items from $startDir
		list($dirs, $titles)=getDirsAndTitles($startDir);

		if ($comingFrom!=='') // if coming from a subdirectory, then start searching from this directory
		{
			$comingFrom=lastDirInString($comingFrom);
			$comingFromIndex=array_search($comingFrom, $dirs);
			if (($comingFromIndex!==false) and isset($dirs[$comingFromIndex+1])) // if there is a next directory
			{
				$result=findFirstTitleFrom($startDir.$dirs[$comingFromIndex+1].'/', true); // search next sibling directory
				if ($result!=false)
				{
					return $result;
				}
			}
			else // there is no more directories to enter. Search one dir up
			{
				if (($startDir==='') and !LOOP) // if at root level and loop is not active then return 'stop' to stop playing
				{
					return [$startDir, 'stop'];
				}
				$parentDirIsRoot=(parentDir($startDir)===''); // if parent dir is root, then allow tracks from startDir(root)
				$result=findFirstTitleFrom(parentDir($startDir), $parentDirIsRoot, $startDir);
				if ($result!=false)
				{
					return $result;
				}
			}
		}

		// if $getTracksFromStartDir and there are audio files in $startDir
		if ($getTracksFromStartDir and (count($titles)>0))
		{
			return [$startDir, $titles];
		}

		// if there are subdirectories in the directory
		if (count($dirs)>0)
		{
			$result=findFirstTitleFrom($startDir.$dirs[0].'/', true); // start from top
			if ($result!=false)
			{
				return $result;
			}
		}
		
		// if there are no subdirectories in the directory, then search parent directory starting from this directory
		$result=findFirstTitleFrom(parentDir($startDir), false, $startDir);
		if ($result!=false)
		{
			return $result;
		}

		return false;
	}


	function echoReqHtml($data,$func)
	{
		echo'<!DOCTYPE html><html><head><meta charset="'.CHARSET.'"><script>var dataContainer='.ea($data).';</script></head><body onload="parent.'.$func.'(dataContainer)"></body></html>';
	}


	function skipButton($arr)
	{
		$result='';
		if(isset($arr) and is_array($arr))
		{
			foreach($arr as $val)
			{
				$result.='<div class="button" onclick="skipSec('.$val.')">'.($val>0?'+':'').$val.'</div>';
			}
		}
		return $result;
	}


	mb_internal_encoding(CHARSET);
	header('Content-Type: text/html; charset="'.CHARSET.'"');


	if(isset($_POST['dffunc']))
	{
		$func=$_POST['dffunc'];
		$data=$_POST['dfdata'];
		if($func=='dir')
		{
			$dir=$data;
			$titles=[];
			$dirs=[];
			if((mb_strpos('./'.$dir,'/../')===false) and (mb_substr('./'.$dir,-1)==='/') and (mb_strpos($dir,'\\')===false))
			{
				list($dirs, $titles)=getDirsAndTitles($dir);
				$status='ok';
			}
			else
			{
				$status=TXT_ACC_DIR;
				$dir='';
				$dirs='';
				$titles='';
			}
			echoReqHtml([$status,$dir,$dirs,$titles],'getBrowserData');
			exit();
		}
		if($func=='searchTitle')
		{
			$message='';
			$titles=[];
			$searchStr=trim($data);
			if(mb_strlen($searchStr)<MIN_SEARCH_STR)
			{
				$message=TXT_MIN_SEARCH.MIN_SEARCH_STR;
			}
			else
			{
				if($searchStr!=='')
				{
					$titles=searchForTitle($searchStr);
					if(count($titles)>MAX_SEARCH_RESULT)
					{
						$message=TXT_TOO_MANY.MAX_SEARCH_RESULT;
						$titles=array_slice($titles,0,MAX_SEARCH_RESULT);
					}
				}
			}
			sort($titles, SORT_FLAG_CASE | SORT_NATURAL);
			echoReqHtml([$message,$titles],'getSearchTitle');
			exit();
		}
		if($func=='searchDir')
		{
			$message='';
			$dir=[];
			$searchStr=trim($data);
			if(mb_strlen($searchStr)<MIN_SEARCH_STR)
			{
				$message=TXT_MIN_SEARCH.MIN_SEARCH_STR;
			}
			else
			{
				if($searchStr!=='')
				{
					$dir=searchForDir($searchStr);
					if(count($dir)>MAX_SEARCH_RESULT)
					{
						$message=TXT_TOO_MANY.MAX_SEARCH_RESULT;
						$dir=array_slice($dir,0,MAX_SEARCH_RESULT);
					}
				}
			}
			sort($dir, SORT_FLAG_CASE | SORT_NATURAL);
			echoReqHtml([$message,$dir],'getSearchDir');
			exit();
		}
		if($func=='treePlay')
		{
			$error=false;
			$splitData=explode('|', $data);
			$dir=$splitData[0];
			$loop=($splitData[1]==='loopOn'?true:false);
			define('LOOP', $loop);
			$titles=[];

			if((mb_strpos('./'.$dir,'/../')===false) and (mb_substr('./'.$dir,-1)==='/') and (mb_strpos($dir,'\\')===false))
			{
				$result=findFirstTitleFrom($dir, false);
				if ($result!=false)
				{
					$dir=$result[0];
					$titles=$result[1];
				}
			}
			else
			{
				$error=true;
			}
			if($error)
			{
				$status=TXT_ACC_DIR;
				$dir='';
				$titles='';
			}
			else
			{
				$status='ok';
			}
			echoReqHtml([$status,$dir,$titles],'getNextTreeDirTracks');
			exit();
		}
		exit();
	}


	define('ICON_PLAY', '<svg width="1em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="-7 0 32 32" xmlns="http://www.w3.org/2000/svg"><path d="M0 6.688v18.906c0 0.344 0.156 0.625 0.469 0.813 0.125 0.094 0.344 0.125 0.5 0.125s0.281-0.031 0.438-0.125l16.375-9.438c0.313-0.219 0.5-0.5 0.5-0.844 0-0.313-0.188-0.594-0.5-0.813l-16.375-9.438c-0.563-0.406-1.406 0.094-1.406 0.813z"></path></svg>');
	define('ICON_PAUSE', '<svg width="0.9em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg"><path d="M5.92 24.096q0 0.832 0.576 1.408t1.44 0.608h4.032q0.832 0 1.44-0.608t0.576-1.408v-16.16q0-0.832-0.576-1.44t-1.44-0.576h-4.032q-0.832 0-1.44 0.576t-0.576 1.44v16.16zM18.016 24.096q0 0.832 0.608 1.408t1.408 0.608h4.032q0.832 0 1.44-0.608t0.576-1.408v-16.16q0-0.832-0.576-1.44t-1.44-0.576h-4.032q-0.832 0-1.408 0.576t-0.608 1.44v16.16z"></path></svg>');
	define('ICON_STOP', '<svg width="0.85em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg"><path d="M5.92 24.096q0 0.832 0.576 1.408t1.44 0.608h16.128q0.832 0 1.44-0.608t0.576-1.408v-16.16q0-0.832-0.576-1.44t-1.44-0.576h-16.128q-0.832 0-1.44 0.576t-0.576 1.44v16.16z"></path></svg>');
	define('ICON_NEXT', '<svg width="0.9em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 100 100" xml:space="preserve"><g><path d="M88.765,77.291v-54.72c0-0.002,0.001-0.003,0.001-0.005s-0.001-0.004-0.001-0.005v-0.235h-0.024 c-0.123-1.286-1.194-2.296-2.513-2.296c-0.03,0-0.058,0.008-0.087,0.009h-4.569c-0.071-0.006-0.14-0.021-0.213-0.021 c-1.4,0-2.537,1.136-2.537,2.537c0,0.117,0.019,0.23,0.035,0.343v23.141l-33.341-19.25c-0.31-0.307-0.736-0.497-1.207-0.497 c-0.932,0-1.686,0.743-1.713,1.669H42.59v15.249L14.148,26.788c-0.31-0.307-0.736-0.497-1.207-0.497 c-0.932,0-1.687,0.743-1.713,1.669h-0.005v44.031c0,0.949,0.77,1.718,1.718,1.718c0.483,0,0.918-0.2,1.23-0.521L42.59,56.78v15.212 c0,0.949,0.769,1.718,1.718,1.718c0.483,0,0.918-0.2,1.23-0.521l33.319-19.237v23.382h0.013c-0.002,0.039-0.012,0.075-0.012,0.114 c0,1.399,1.134,2.533,2.532,2.536v0h4.852v-0.024c1.401,0,2.537-1.136,2.537-2.537C88.778,77.377,88.767,77.335,88.765,77.291z"/></g></svg>');
	define('ICON_PREVIOUS', '<svg width="0.9em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 100 100" xml:space="preserve"><g><path d="M87.06,26.291c-0.483,0-0.918,0.2-1.23,0.521L57.41,43.22V28.009c0-0.949-0.769-1.718-1.718-1.718 c-0.483,0-0.918,0.2-1.23,0.521L21.144,46.049V22.667h-0.013c0.002-0.039,0.012-0.075,0.012-0.114c0-1.399-1.134-2.533-2.532-2.536 v0h-4.852v0.024c-1.401,0-2.537,1.136-2.537,2.537c0,0.045,0.011,0.086,0.013,0.131v54.721c0,0.002,0,0.003,0,0.005 s0,0.003,0,0.005v0.236h0.024c0.123,1.286,1.194,2.296,2.513,2.296c0.03,0,0.058-0.008,0.087-0.009h4.569 c0.071,0.006,0.14,0.021,0.213,0.021c1.4,0,2.537-1.136,2.537-2.537c0-0.117-0.019-0.23-0.035-0.343V53.962l33.341,19.25 c0.31,0.307,0.736,0.497,1.207,0.497c0.932,0,1.686-0.743,1.713-1.669h0.005V56.791l28.443,16.422 c0.31,0.307,0.736,0.497,1.207,0.497c0.932,0,1.687-0.743,1.713-1.669h0.005V28.009C88.778,27.06,88.008,26.291,87.06,26.291z"/></g></svg>');
	define('ICON_MARK', '&#9733;');
	define('ICON_LOAD', '<svg width="0.5em" height="0.5em" fill="var(--CLR_TEXT)" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg"><path d="M8 3a5 5 0 100 10A5 5 0 008 3z"/></svg>');
	define('ICON_ARROW', ' &#10137; ');
	define('ICON_SHUFFLE', '<svg width="1em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 256 256" xmlns="http://www.w3.org/2000/svg"><path d="M241.58984,191.19238c-.10351.13733-.19873.27845-.30859.41211-.25195.30725-.51758.60279-.79834.88343l-23.99756,23.99743a12.0001,12.0001,0,0,1-16.9707-16.9707L203.0293,196H172.11719a20.03724,20.03724,0,0,1-16.27442-8.375L81.82422,84H32a12,12,0,0,1,0-24H83.88281a20.03726,20.03726,0,0,1,16.27442,8.375L174.17578,172H203.0293l-3.51465-3.51465a12.0001,12.0001,0,0,1,16.9707-16.9707l23.99756,23.99743c.28076.28064.54639.57618.79834.88343.10986.13366.20508.27478.30859.41211.13184.17541.26758.34753.38965.53027.11328.169.21094.34424.31446.51746.09716.16247.19921.32141.28857.48877.0957.17859.17676.36218.26221.54431.08154.17261.168.34228.24121.51916.07373.17884.13379.36145.19873.543.06738.18762.13916.37293.19726.5647.05616.1842.09668.37146.14356.55762.04834.19311.10254.38366.1416.5802.04346.219.06982.43994.10107.6604.02344.167.05518.33105.07178.50024a12.03715,12.03715,0,0,1,0,2.37256c-.0166.16919-.04834.33325-.07178.50024-.03125.22046-.05761.44141-.10107.6604-.03906.19654-.09326.38709-.1416.5802-.04688.18616-.0874.37342-.14356.55762-.0581.19214-.13037.37756-.19775.56543-.06445.18115-.12451.36353-.19824.542-.07324.17725-.15967.34717-.24121.52014-.08594.18189-.16651.36524-.26221.54358-.08936.16736-.19141.3263-.28857.48877-.10352.17322-.20118.34851-.31446.51746C241.85742,190.84485,241.72168,191.017,241.58984,191.19238ZM110.39648,152.64453a11.998,11.998,0,0,0-16.73925,2.79L81.82422,172H32a12,12,0,0,0,0,24H83.88281a20.03726,20.03726,0,0,0,16.27442-8.375l13.02929-18.24121A11.99859,11.99859,0,0,0,110.39648,152.64453Zm35.207-49.28906a11.99655,11.99655,0,0,0,16.73925-2.79L174.17578,84H203.0293l-3.51465,3.51465a12.0001,12.0001,0,0,0,16.9707,16.9707l24-24c.02979-.02954.0542-.06225.083-.092.24707-.25195.48584-.51221.71-.785.12354-.15052.23145-.309.34668-.464.11816-.15869.24121-.31324.35156-.47779.12012-.17993.2251-.3667.335-.55151.08985-.15173.18555-.29968.269-.45557.09961-.186.18408-.37719.27343-.56713.07764-.16553.16016-.32789.23047-.49732.07666-.18481.13867-.37353.20557-.56128.06494-.18176.13476-.361.19141-.54663.05712-.18945.0996-.38184.14746-.57324.04687-.18848.10009-.374.13818-.56592.04395-.22131.07031-.44482.10156-.66772.02344-.16492.05518-.32691.07129-.49378a12.03958,12.03958,0,0,0,0-2.3728c-.01611-.16687-.04785-.32886-.07129-.49378-.03125-.2229-.05761-.44641-.10156-.66772-.03809-.19189-.09131-.37744-.13818-.56592-.04786-.1914-.09034-.38379-.14746-.57324-.05665-.18567-.12647-.36487-.19141-.54663-.0669-.18762-.12891-.37647-.20557-.56128-.07031-.16956-.15283-.332-.231-.49756-.08887-.18982-.17334-.38086-.273-.56689-.0835-.15589-.1792-.30384-.269-.45557-.10986-.18481-.21484-.37158-.335-.55151-.11035-.16455-.2334-.3191-.35156-.47779-.11523-.155-.22314-.31347-.34668-.464-.22412-.27282-.46289-.53308-.71-.785-.02881-.02979-.05322-.0625-.083-.092l-24-24a12.0001,12.0001,0,0,0-16.9707,16.9707L203.0293,60H172.11719a20.03724,20.03724,0,0,0-16.27442,8.375L142.81348,86.61621A11.99859,11.99859,0,0,0,145.60352,103.35547Z"/></svg>');
	define('ICON_LOOP', '<svg width="1em" height="1.35em" fill="none" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path d="M18 4L21 7M21 7L18 10M21 7H7C4.79086 7 3 8.79086 3 11M6 20L3 17M3 17L6 14M3 17H17C19.2091 17 21 15.2091 21 13" stroke="var(--CLR_TEXT)" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/></svg>');
	define('ICON_TREE', '<svg width="0.9em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 48 48" xmlns="http://www.w3.org/2000/svg"><path d="M26,30H42a2,2,0,0,0,2-2V20a2,2,0,0,0-2-2H26a2,2,0,0,0-2,2v2H16V14h6a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v8a2,2,0,0,0,2,2h6V40a2,2,0,0,0,2,2H24v2a2,2,0,0,0,2,2H42a2,2,0,0,0,2-2V36a2,2,0,0,0-2-2H26a2,2,0,0,0-2,2v2H16V26h8v2A2,2,0,0,0,26,30Z"/></svg>');
	define('ICON_SETTINGS', '<svg width="1.2em" height="1.2em" fill="var(--CLR_TEXT)" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"> <path fill-rule="evenodd" clip-rule="evenodd" d="M4 5C3.44772 5 3 5.44772 3 6C3 6.55228 3.44772 7 4 7H20C20.5523 7 21 6.55228 21 6C21 5.44772 20.5523 5 20 5H4ZM3 12C3 11.4477 3.44772 11 4 11H20C20.5523 11 21 11.4477 21 12C21 12.5523 20.5523 13 20 13H4C3.44772 13 3 12.5523 3 12ZM3 18C3 17.4477 3.44772 17 4 17H20C20.5523 17 21 17.4477 21 18C21 18.5523 20.5523 19 20 19H4C3.44772 19 3 18.5523 3 18Z"/></svg>');
	define('ICON_DARK_THEME', '<svg width="0.8em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 48 48" xmlns="http://www.w3.org/2000/svg"><path d="M24.2,5h-.1a19.2,19.2,0,0,0-17,21.1A19.2,19.2,0,0,0,24.2,42.9h2.1a19.2,19.2,0,0,0,14.4-6.4A.9.9,0,0,0,40,35H38.1c-8.8-.5-16.6-8.4-16.9-17.1A17.4,17.4,0,0,1,25,6.6,1,1,0,0,0,24.2,5Z"/></svg>');
	define('ICON_LIGHT_THEME', '<svg width="0.8em" height="1.35em" fill="var(--CLR_TEXT)" viewBox="0 0 64 64" xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 64 64" xml:space="preserve"><g><circle fill-rule="evenodd" clip-rule="evenodd" cx="32.003" cy="32.005" r="16.001"/><path fill-rule="evenodd" clip-rule="evenodd" d="M12.001,31.997c0-2.211-1.789-4-4-4H4c-2.211,0-4,1.789-4,4s1.789,4,4,4h4C10.212,35.997,12.001,34.208,12.001,31.997z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M12.204,46.139l-2.832,2.833c-1.563,1.562-1.563,4.094,0,5.656c1.562,1.562,4.094,1.562,5.657,0l2.833-2.832c1.562-1.562,1.562-4.095,0-5.657C16.298,44.576,13.767,44.576,12.204,46.139z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M32.003,51.999c-2.211,0-4,1.789-4,4V60c0,2.211,1.789,4,4,4s4-1.789,4-4l-0.004-4.001C36.003,53.788,34.21,51.999,32.003,51.999z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M51.798,46.143c-1.559-1.566-4.091-1.566-5.653-0.004s-1.562,4.095,0,5.657l2.829,2.828c1.562,1.57,4.094,1.562,5.656,0s1.566-4.09,0-5.656L51.798,46.143z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M60.006,27.997l-4.009,0.008c-2.203-0.008-3.992,1.781-3.992,3.992c-0.008,2.211,1.789,4,3.992,4h4.001c2.219,0.008,4-1.789,4-4C64.002,29.79,62.217,27.997,60.006,27.997z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M51.798,17.859l2.828-2.829c1.574-1.566,1.562-4.094,0-5.657c-1.559-1.567-4.09-1.567-5.652-0.004l-2.829,2.836c-1.562,1.555-1.562,4.086,0,5.649C47.699,19.426,50.239,19.418,51.798,17.859z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M32.003,11.995c2.207,0.016,4-1.789,4-3.992v-4c0-2.219-1.789-4-4-4c-2.211-0.008-4,1.781-4,3.993l0.008,4.008C28.003,10.206,29.792,11.995,32.003,11.995z"/><path fill-rule="evenodd" clip-rule="evenodd" d="M12.212,17.855c1.555,1.562,4.079,1.562,5.646-0.004c1.574-1.551,1.566-4.09,0.008-5.649l-2.829-2.828c-1.57-1.571-4.094-1.559-5.657,0c-1.575,1.559-1.575,4.09-0.012,5.653L12.212,17.855z"/></g></svg>');
	define('ICON_OS_THEME', '<svg width="0.8em" height="1.35em" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g fill="var(--CLR_TEXT)" fill-rule="nonzero"><path d="M12,22 C17.5228475,22 22,17.5228475 22,12 C22,6.4771525 17.5228475,2 12,2 C6.4771525,2 2,6.4771525 2,12 C2,17.5228475 6.4771525,22 12,22 Z M12,20 L12,4 C16.418278,4 20,7.581722 20,12 C20,16.418278 16.418278,20 12,20 Z"></path></g></g></svg>');


?><!DOCTYPE html>
<html data-theme="light">
<head>
	<meta charset="<?php echo CHARSET;?>">
	<title><?php echo TXT_PLAYER_TITLE; ?></title>
	<meta name="viewport" content="width=device-width,initial-scale=1,maximum-scale=1,user-scalable=no">
	<meta name="apple-mobile-web-app-capable" content="yes">
	<meta name="theme-color" content="<?php echo CLR_DARK_BACK; ?>">
	<meta name="mobile-web-app-capable" content="yes">
	<style>

		[data-theme="light"]
		{
			--CLR_BACK: <?php echo CLR_LIGHT_BACK; ?>;
			--CLR_TEXT: <?php echo CLR_LIGHT_TEXT; ?>;
			--CLR_TEXT_SMALL: <?php echo CLR_LIGHT_TEXT_SMALL; ?>;
			--CLR_TAB: <?php echo CLR_LIGHT_TAB; ?>;
			--CLR_TAB_ACT: <?php echo CLR_LIGHT_TAB_ACT; ?>;
			--CLR_BUTTON: <?php echo CLR_LIGHT_BUTTON; ?>;
			--CLR_LED_DISABLED: <?php echo CLR_LIGHT_LED_DISABLED; ?>;
			--CLR_LED_ON: <?php echo CLR_LIGHT_LED_ON; ?>;
			--CLR_LED_OFF: <?php echo CLR_LIGHT_LED_OFF; ?>;
			--CLR_TIME_BOX: <?php echo CLR_LIGHT_TIME_BOX; ?>;
			--CLR_TRACK_BOX: <?php echo CLR_LIGHT_TRACK_BOX; ?>;
			--CLR_PATH: <?php echo CLR_LIGHT_PATH; ?>;
			--CLR_DIR: <?php echo CLR_LIGHT_DIR; ?>;
			--CLR_TRACK: <?php echo CLR_LIGHT_TRACK; ?>;
			--CLR_TRACK_HL: <?php echo CLR_LIGHT_TRACK_HL; ?>;
			--CLR_SEARCH: <?php echo CLR_LIGHT_SEARCH; ?>;
			--CLR_COLLECTION: <?php echo CLR_LIGHT_COLLECTION; ?>;
			--CLR_TEXT_ERROR: <?php echo CLR_LIGHT_TEXT_ERROR; ?>;
			--CLR_SCROLLBAR_TRACK: <?php echo CLR_LIGHT_SCROLLBAR_TRACK; ?>;
			--CLR_SCROLLBAR_THUMB: <?php echo CLR_LIGHT_SCROLLBAR_THUMB; ?>;
		}

		[data-theme="dark"]
		{
			--CLR_BACK: <?php echo CLR_DARK_BACK; ?>;
			--CLR_TEXT: <?php echo CLR_DARK_TEXT; ?>;
			--CLR_TEXT_SMALL: <?php echo CLR_DARK_TEXT_SMALL; ?>;
			--CLR_TAB: <?php echo CLR_DARK_TAB; ?>;
			--CLR_TAB_ACT: <?php echo CLR_DARK_TAB_ACT; ?>;
			--CLR_BUTTON: <?php echo CLR_DARK_BUTTON; ?>;
			--CLR_LED_DISABLED: <?php echo CLR_DARK_LED_DISABLED; ?>;
			--CLR_LED_ON: <?php echo CLR_DARK_LED_ON; ?>;
			--CLR_LED_OFF: <?php echo CLR_DARK_LED_OFF; ?>;
			--CLR_TIME_BOX: <?php echo CLR_DARK_TIME_BOX; ?>;
			--CLR_TRACK_BOX: <?php echo CLR_DARK_TRACK_BOX; ?>;
			--CLR_PATH: <?php echo CLR_DARK_PATH; ?>;
			--CLR_DIR: <?php echo CLR_DARK_DIR; ?>;
			--CLR_TRACK: <?php echo CLR_DARK_TRACK; ?>;
			--CLR_TRACK_HL: <?php echo CLR_DARK_TRACK_HL; ?>;
			--CLR_SEARCH: <?php echo CLR_DARK_SEARCH; ?>;
			--CLR_COLLECTION: <?php echo CLR_DARK_COLLECTION; ?>;
			--CLR_TEXT_ERROR: <?php echo CLR_DARK_TEXT_ERROR; ?>;
			--CLR_SCROLLBAR_TRACK: <?php echo CLR_DARK_SCROLLBAR_TRACK; ?>;
			--CLR_SCROLLBAR_THUMB: <?php echo CLR_DARK_SCROLLBAR_THUMB; ?>;
		}

		/* info: fix to have iOS render outside view-area */
		body *
		{
			-webkit-transform:translate3d(0,0,0);
		}

		body
		{
			font-size:5vw;
			color: var(--CLR_TEXT);
			font-family: Arial,Helvetica Neue,Helvetica,sans-serif;
			-webkit-touch-callout: none;
			-webkit-user-select: none;
			-khtml-user-select: none;
			-moz-user-select: none;
			-ms-user-select: none;
			user-select: none;
			-webkit-overflow-scrolling:touch;
			background: var(--CLR_BACK);
			scrollbar-color: var(--CLR_SCROLLBAR_THUMB) var(--CLR_SCROLLBAR_TRACK);
		}

		html
		{
			background: var(--CLR_BACK);
		}

		smallPath,error
		{
			position:relative;
			top: -0.55em;
			font-size:65%;
			color: var(--CLR_TEXT_SMALL);
		}

		error
		{
			color: var(--CLR_TEXT_ERROR);
		}		

		.txtCenter
		{
			text-align:center;
		}

		.inp
		{
			font-size:90%;
			width:9em;
			border:none;
			background: var(--CLR_SEARCH);
			color: var(--CLR_TEXT);
			border-radius:0.1em;
		}

		.hideout
		{
			position:absolute;
			left:0em;
			top:0em;
			visibility:hidden;
		}

		.fixedMenu
		{
			position:fixed;
			top:0em;
			left:0em;
			width:100%;
			height:8.3em;
			text-align:left;
			padding:0em;
			background: var(--CLR_BACK);
			z-index:100;
		}

		.timeBox
		{
			text-align:center;
			display:inline-block;
			width:30%;
			background: var(--CLR_TIME_BOX);
			border-radius:0.1em;
			margin:0.4em 1% 0.45em 2%;
		}

		.bar
		{
			width:100%;
			height:1.65em;
			padding:0em 0em 0em 0.25em;
			margin:0em;
		}

		.barOn,.barOff,.barGrey
		{
			border-radius:0.1em;
			cursor:pointer;
			display:inline-block;
			background: var(--CLR_LED_OFF);
			border:none;
			width:1.2em;
			height:1.2em;
			margin:0% 0% 0% 0.9%;
		}

		.barOn
		{
			background: var(--CLR_LED_ON);
		}

		.barGrey
		{
			background: var(--CLR_LED_DISABLED);
		}

		.trackName
		{
			cursor:pointer;
			width:96%;
			height:2em;
			text-align:center;
			white-space:nowrap;
			overflow:auto;
			overflow-y:hidden;
			background: var(--CLR_TRACK_BOX);
			border-radius:0.1em;
			display:inline-block;
			margin:0em 0em 0.5em 0.4em;
			vertical-align:top;
		}

		.tabBack
		{
			background: var(--CLR_BACK);
			text-align:center;
			position:fixed;
			top:0;
			left:0em;
			width:100%;
			height:10.4em;
			z-index:50;
		}

		.tabBrowser,.tabPlaylist,.tabSearch,.tabSettings
		{
			text-align:center;
			cursor:pointer;
			position:absolute;
			bottom:0;
			left:2%;
			width:26%;
			height:1.7em;
			border-radius:0.3em 0.3em 0em 0em;
		}

		.tabPlaylist
		{
			left:30%;
		}

		.tabSearch
		{
			left:58%;
		}

		.tabSettings
		{
			width:12%;
			left:86%;
		}

		.tabTextAlign
		{
			padding-top: 0.2em;
		}

		.tabFrame,.tabFrameBack
		{
			overflow:hidden;
			overflow-y:auto;
			position:absolute;
			top:10.60em;
			left:0em;
			bottom:0em;
			width:100%;
			background: var(--CLR_TAB_ACT);
			z-index:10;
		}

		.tabFrameBack
		{
			border-radius:0.1em;
			overflow:hidden;
			top:10.4em;
			z-index:0;
			position:fixed;
		}

		.listContainer
		{
			overflow:hidden;
			white-space:nowrap;
			width:98%;
			height:2em;
			margin:0em 0em 0.2em 0.2em;
		}

		.browserPath,.browserDir,.browserTitle,.browserTitleHL,.browserAction
		{
			cursor:pointer;
			vertical-align:top;
			border-radius:0.1em;
			overflow:hidden;
			white-space:nowrap;
			display:inline-block;
			background: var(--CLR_TRACK);
			height:100%;
			margin:0% 1% 0% 0%;
		}

		.browserPath
		{
			background: var(--CLR_PATH);
		}

		.browserDir
		{
			background: var(--CLR_DIR);
			width:100%;
		}

		.browserTitle,.browserTitleHL
		{
			width:89%;
		}

		.browserTitleHL
		{
			background: var(--CLR_TRACK_HL);
		}

		.touchDevice .overflowAuto
		{
			overflow-x:auto;
		}
		
		.overflowAuto:hover
		{
			overflow-x:auto;
		}

		.browserAction
		{
			width:10%;
		}

		.w25p
		{
			width:25%;
		}

		.w48p
		{
			width:48%;
		}

		.paddingTop
		{
			line-height:1.9;
		}

		.mark
		{
			position:relative;
			left:0.5em;
			top:0.2em;
		}

		.markPlay
		{
			visibility:hidden;
			position:absolute;
			font-size:50%;
			left:0.3em;
			top:0.1em;
		}

		.markLoad
		{
			visibility:hidden;
			position:absolute;
			font-size:100%;
			right:0.1em;
			top:-0.32em;
			animation: blinker 1s linear infinite;
		}
		
		@keyframes blinker
		{  
			50% {opacity: 0.0;}
		}

		.button,.buttonSmallOn,.buttonSmallOff
		{
			line-height:1.37;
			display:inline-block;
			overflow:hidden;
			font-size:150%;
			height:1.35em;
			width:22.5%;
			cursor:pointer;
			background: var(--CLR_BUTTON);
			border:none;
			border-radius:0.1em;
			text-align:center;
			padding:0;
			margin:0 0 0.1em 2%;
		}

		.buttonSmallOn,.buttonSmallOff
		{
			width:10%;
		}		

		.description
		{
			display:inline-block;
			overflow:hidden;
			font-size:75%;
			width:80%;
			height:2.7em;
			text-align:left;
			padding:0 0 0 0.75em;
			margin:0;
		}
		
		.buttonSmallOn
		{
			background: var(--CLR_TAB_ACT);
		}
		
		.collection, .collectionLS
		{
			display:inline-block;
			overflow:hidden;
			width:98%;
			background: var(--CLR_COLLECTION);
			border:none;
			border-radius:0.1em;
			text-align:left;
			padding:0.4em 0 0 0;
			margin:0 0 -0.05em 1%;
		}

		.collectionLS
		{
			width:96%;
			margin:0 0 -0.05em 2%;
		}		

		.landscape
		{
			visibility:hidden;
		}

		.txtVCenter
		{
			display:flex;
			justify-content:center;
			align-items:center;
			height:100%;
		}
		
		.cursorPointer
		{
			cursor:pointer;
		}

		@media all and (orientation:landscape)
		{
			body
			{
				font-size:2.5vw;
			}

			.landscape
			{
				visibility:visible;
			}

			.fixedMenu
			{
				width:50%;
			}

			.tabFrame,.tabFrameBack
			{
				top:2.1em;
				left:50%;
				bottom:0em;
				width:50%;
			}

			.tabFrame
			{
				top:2.3em;
			}

			.tabBack
			{
				top:0;
				left:50%;
				width:50%;
				height:2.1em;
			}

		}

	</style>
	<script>
		var player;
		var playingFrom='';
		var browserPlaylistTitles=[];
		var browserPlaylistDir='';
		var playlistTracks=[];
		var browserCurDir;
		var browserCurDirs=[];
		var browserDirs=[];
		var browserTitles=[];
		var searchDirs=[];
		var searchDirTracks=[];
		var searchplaylistTracks=[];
		var playing=0;
		var playingTrack='';
		var lastProgress=-1;
		var tabShowing='';
		var loading=false;
		var dataframeTime=0;
		var searchString='';
		var searchAction='';
		var shuffledList=[];
		var shuffle=getShuffle();
		var loop=getLoop();
		var tree=getTree();
		var themeCurrent=themeGetDefault();
		var errorHandling=false;
		var errorCounter=0;
		var errorAbortCodes=[1,2,3,4]; // 1=MEDIA_ERR_ABORTED, 2=MEDIA_ERR_NETWORK, 3=MEDIA_ERR_DECODE, 4=MEDIA_ERR_SRC_NOT_SUPPORTED


		function isTouchDevice()
		{
			return navigator.maxTouchPoints > 0;
		}


		if (isTouchDevice())
		{
			document.addEventListener("DOMContentLoaded", function () { document.body.classList.add("touchDevice"); });
		}


		function getBrowserData(data)
		{
			loading=false;
			markLoading(false);
			if(String(data[0])=='ok')
			{
				browserCurDir=(String(data[1]));
				var tmpArr=browserCurDir.split('/');
				browserCurDirs=[];
				for(var i=0;i<tmpArr.length;i++)
				{
					if(tmpArr[i]!='')
					{
						browserCurDirs[browserCurDirs.length]=tmpArr[i];
					}
				}
				browserDirs=data[2];
				browserTitles=data[3];
				gebi('frameBrowser').scrollTop=0;
				updateBrowser();
			}
			else
			{
				alert(data[0]);
			}
		}


		function getSearchTitle(data)
		{
			loading=false;
			markLoading(false);
			searchDirs=[];
			searchDirTracks=data[1];
			updateSearch('title');
			if(data[0]!='')
			{
				alert(data[0]);
			}
		}


		function getSearchDir(data)
		{
			loading=false;
			markLoading(false);
			searchDirTracks=[];
			searchDirs=data[1];
			updateSearch('dir');
			if(data[0]!='')
			{
				alert(data[0]);
			}
		}


		function getNextTreeDirTracks(data)
		{
			loading=false;
			markLoading(false);
			if(String(data[0])=='ok')
			{
				if (data[2]==='stop')
				{
					playerStop(true);
					return;
				}
				browserPlaylistDir=(String(data[1]));
				browserPlaylistTitles=data[2];
				playing=0;
				if (shuffle)
				{
					playing=Math.floor(Math.random()*browserPlaylistTitles.length);
				}
				setAndPlayTrack(browserPlaylistDir+browserPlaylistTitles[playing]);
			}
			else
			{
				alert(data[0]);
			}
		}


		function init()
		{
			themeUpdate();
			shuffleUpdateButton();
			loopUpdateButton();
			treeUpdateButton();
			window.onbeforeunload = function() { return '<?php echo TXT_EXIT; ?>'; };
			checkDataframe();
			showTab('browser');
			markPlayingTab('');
			player=gebi('player');
			loadPlaylist();
			updateProgressBar();
			browseDir();
			updateAllLists();
			player.onended = function()
			{
				changeTrack(1);
			}
			player.onpause = function()
			{
				gebi('buttonPlay').innerHTML='<?php echo ICON_PLAY; ?>';
			}
			player.onplaying = function()
			{
				gebi('buttonPlay').innerHTML='<?php echo ICON_PAUSE; ?>';
			}
			player.ontimeupdate = function()
			{
				updateProgressBar();
			}
			player.onloadedmetadata = function()
			{
				updateProgressBar();
			}
			player.onerror = function()
			{
				if (!errorHandling)
				{
					if (errorAbortCodes.indexOf(player.error.code)!==-1)
					{
						errorCounter++;
						if (errorCounter>999)
						{
							errorCounter=0;
						}
						errorHandling=true;
						playerErrorHandler(<?php echo ERROR_NEXT_SEC; ?>, errorCounter);
					}
				}
			}
		}


		function playerErrorHandler(time, counter)
		{
			if (errorHandling && counter===errorCounter)
			{
				if (errorAbortCodes.indexOf(player.error.code)!==-1)
				{
					if (time<1)
					{
						errorHandling=false;
						changeTrack(1);
					}
					else
					{
						gebi('trackName').innerHTML='&nbsp;'+getTrackTitle(playingTrack)+'<br>&nbsp;<error><?php echo TXT_TRACK_ERROR; ?></error>';
						setTimeout(function () { playerErrorHandler(time-1, counter); }, 1000);
					}
				}
				else
				{
					errorHandling=false;
				}
			}
		}


		function markLoading(tab)
		{
			
			if(tab=='browser')
			{
				gebi('markLoadBrowser').style.visibility='visible';
				gebi('markLoadSearch').style.visibility='hidden';
			}
			else if(tab=='search')
			{
				gebi('markLoadBrowser').style.visibility='hidden';
				gebi('markLoadSearch').style.visibility='visible';
			}
			else
			{
				gebi('markLoadBrowser').style.visibility='hidden';
				gebi('markLoadSearch').style.visibility='hidden';
			}
		}


		function secondsToTime(secs)
		{
			var negative=false;
			if(secs!=secs)
			{
				return '';
			}
			if(secs<0)
			{
				secs*=-1;
				negative=true;
			}
			var hh = Math.floor(secs/3600);
			var mm = Math.floor(secs/60)%60;
			var ss = Math.floor(secs)%60;
			return (negative?'-':'')+(hh<10?'0':'')+hh+':'+(mm<10?'0':'')+mm+':'+(ss<10?'0':'')+ss;
		}


		function updateProgressBar()
		{
			var leds=14;
			var cur=player.currentTime;
			var max=player.duration;
			if((cur!=cur)||(max!=max)||(cur>max)||isNaN(cur)||isNaN(max)||!isFinite(cur)||!isFinite(max))
			{
				var bar='';
				lastProgress=progress;
				for(var i=0;i<leds;i++)
				{
					bar+='<div class="barGrey"></div>';
				}
				gebi('bar').innerHTML=bar;
				gebi('trackCurrentTime').innerHTML=secondsToTime(0);
				gebi('trackRemaining').innerHTML=secondsToTime(0);
				gebi('trackDuration').innerHTML=secondsToTime(0);
			}
			else
			{
				gebi('trackCurrentTime').innerHTML=secondsToTime(Math.floor(cur));
				gebi('trackRemaining').innerHTML=secondsToTime(Math.floor(max)-Math.floor(cur));
				gebi('trackDuration').innerHTML=secondsToTime(max);
				var progress = Math.floor(cur/max*leds);
				if(progress==leds)
				{
					progress=leds-1;
				}
				if(progress!=lastProgress)
				{
					var bar='';
					lastProgress=progress;
					for(var i=0;i<leds;i++)
					{
						bar+='<div class="'+(progress==i?"barOn":"barOff")+'" onClick="player.currentTime='+Math.ceil(max/leds*(i))+'"></div>';
					}
					gebi('bar').innerHTML=bar;
				}
			}
		}


		function loadPlaylist()
		{
			var playlistLS=localStorage.getItem('playlist');
			if (playlistLS)
			{
				playlistTracks=playlistLS.split('|');
			}
		}


		function savePlaylist()
		{
			localStorage.setItem('playlist', playlistTracks.join('|'));
		}


		function gebi(id)
		{
			return document.getElementById(id);
		}


		function skipSec(sec)
		{
			var skipTo=player.currentTime+sec;
			if (skipTo>player.duration)
			{
				skipTo=player.duration-1;
			}
			if (skipTo<0)
			{
				skipTo=0;
			}
			player.currentTime=skipTo;
		}


		function getTree()
		{
			if (localStorage.getItem('tree')==='on')
			{
				return true;
			}
			return false; // default value
		}


		function treeToggle()
		{
			tree=!tree;
			if(tree)
			{
				localStorage.setItem('tree', 'on');
			}
			else
			{
				localStorage.setItem('tree', 'off');
			}
			treeUpdateButton();
		}


		function treeUpdateButton()
		{
			if(tree)
			{
				gebi('tree').className='buttonSmallOn';
			}
			else
			{
				gebi('tree').className='buttonSmallOff';
			}
		}


		function getLoop()
		{
			if (localStorage.getItem('loop')==='off')
			{
				return false;
			}
			return true; // default value
		}


		function loopToggle()
		{
			loop=!loop;
			if(loop)
			{
				localStorage.setItem('loop', 'on');
			}
			else
			{
				localStorage.setItem('loop', 'off');
			}
			loopUpdateButton();
		}


		function loopUpdateButton()
		{
			if(loop)
			{
				gebi('loop').className='buttonSmallOn';
			}
			else
			{
				gebi('loop').className='buttonSmallOff';
			}
		}


		function getShuffle()
		{
			if (localStorage.getItem('shuffle')==='on')
			{
				return true;
			}
			return false; // default value
		}


		function shuffleToggle()
		{
			shuffle=!shuffle;
			if(shuffle)
			{
				updateShuffledList(true);
				localStorage.setItem('shuffle', 'on');
			}
			else
			{
				localStorage.setItem('shuffle', 'off');
			}
			shuffleUpdateButton();
		}


		function shuffleUpdateButton()
		{
			if(shuffle)
			{
				gebi('shuffle').className='buttonSmallOn';
			}
			else
			{
				gebi('shuffle').className='buttonSmallOff';
			}
		}


		function shuffleList(length)
		{
			var i, randomPlace, tmp;
			shuffledList=[];
			for (i=0; i<length; i++)
			{
				shuffledList[i]=i;
			}
			for (i=0; i<length; i++)
			{
				randomPlace=Math.floor(Math.random()*length);
				tmp=shuffledList[i];
				shuffledList[i]=shuffledList[randomPlace];
				shuffledList[randomPlace]=tmp;
			}
			// move playing track to top of shuffled list
			var moveToTopPlace=shuffledList.indexOf(playing);
			if (moveToTopPlace>=0) // if playing have been removed from playlist, then playing is -1 and cant't be moved to top
			{
				tmp=shuffledList[0];
				shuffledList[0]=shuffledList[moveToTopPlace];
				shuffledList[moveToTopPlace]=tmp;
			}
		}


		function updateShuffledList(forceShuffle=false)
		{
			if(playingFrom=='browser')
			{
				if(forceShuffle || (shuffledList.length!=browserPlaylistTitles.length))
				{
					shuffleList(browserPlaylistTitles.length);
				}
			}
			if(playingFrom=='list')
			{
				if(forceShuffle || (shuffledList.length!=playlistTracks.length))
				{
					shuffleList(playlistTracks.length);
				}
			}
			if(playingFrom=='search')
			{
				if(forceShuffle || (shuffledList.length!=searchplaylistTracks.length))
				{
					shuffleList(searchplaylistTracks.length);
				}
			}
		}


		function changeTrack(direction)
		{
			var playNextTrack=true;
			if(shuffle)
			{
				var ply=shuffledList.indexOf(playing)+direction;
				if(ply>shuffledList.length-1)
				{
					if(tree && (playingFrom=='browser'))
					{
						loadNextTreeDirTracks(browserPlaylistDir);
						return; // break here to allow data load from server - starting track from return function
					}
					else
					{
						ply=0;
						if (!loop)
						{
							playNextTrack=false;
						}
					}
				}
				if(ply<0)
				{
					if(loop)
					{
						ply=shuffledList.length-1;
					}
					else
					{
						ply=0;
					}
				}
				playing=shuffledList[ply];
			}
			else
			{
				playing+=direction;
			}
			if(playingFrom=='browser')
			{
				if (playing>browserPlaylistTitles.length-1)
				{
					if(tree)
					{
						loadNextTreeDirTracks(browserPlaylistDir);
						return; // break here to allow data load from server - starting track from return function
					}
					else
					{
						playing=0;
						if (!loop)
						{
							playNextTrack=false;
						}
					}
				}
				else if (playing<0)
				{
					if(loop)
					{
						playing=browserPlaylistTitles.length-1;
					}
					else
					{
						playing=0;
					}
				}
				if (playNextTrack)
				{
					setAndPlayTrack(browserPlaylistDir+browserPlaylistTitles[playing]);
				}
				else
				{
					playerStop(true);
				}
			}
			else if (playingFrom=='list')
			{
				if (playing>playlistTracks.length-1)
				{
					playing=0;
					if (!loop)
					{
						playNextTrack=false;
					}
				}
				else if (playing<0)
				{
					if(loop)
					{
						playing=playlistTracks.length-1;
					}
					else
					{
						playing=0;
					}
				}
				if (playNextTrack)
				{
					setTrackFromPlaylist(playing);
				}
				else
				{
					playerStop(true);
				}
			}
			else if (playingFrom=='search')
			{
				if (playing>searchplaylistTracks.length-1)
				{
					playing=0;
					if (!loop)
					{
						playNextTrack=false;
					}
				}
				else if (playing<0)
				{
					if(loop)
					{
						playing=searchplaylistTracks.length-1;
					}
					else
					{
						playing=0;
					}
				}
				if (playNextTrack)
				{
					setTrackFromSearch(playing);
				}
				else
				{
					playerStop(true);
				}
			}
		}


		function markPlayingTab(tab)
		{
			playingFrom=tab;
			if (playingFrom=='browser')
			{
				gebi('markBrowser').style.visibility='visible';
				gebi('markList').style.visibility='hidden';
				gebi('markSearch').style.visibility='hidden';
			}
			else if (playingFrom=='list')
			{
				gebi('markBrowser').style.visibility='hidden';
				gebi('markList').style.visibility='visible';
				gebi('markSearch').style.visibility='hidden';
			}
			else if (playingFrom=='search')
			{
				gebi('markBrowser').style.visibility='hidden';
				gebi('markList').style.visibility='hidden';
				gebi('markSearch').style.visibility='visible';
			}
			else
			{
				gebi('markBrowser').style.visibility='hidden';
				gebi('markList').style.visibility='hidden';
				gebi('markSearch').style.visibility='hidden';
			}
		}


		function setTrackFromBrowser(id,userChosen=false)
		{
			playing=id;
			markPlayingTab('browser');
			browserPlaylistDir=browserCurDir;
			browserPlaylistTitles=browserTitles;
			if (shuffle)
			{
				updateShuffledList(userChosen);
			}
			setAndPlayTrack(browserCurDir+browserTitles[id]);
		}


		function setTrackFromPlaylist(id,userChosen=false)
		{
			playing=id;
			markPlayingTab('list');
			if (shuffle)
			{
				updateShuffledList(userChosen);
			}
			setAndPlayTrack(playlistTracks[id]);
		}


		function setTrackFromSearch(id,userChosen=false)
		{
			playing=id;
			markPlayingTab('search');
			searchplaylistTracks=searchDirTracks; // creating a hidden list of current search results
			if (shuffle)
			{
				updateShuffledList(userChosen);
			}
			setAndPlayTrack(searchplaylistTracks[id]);
		}


		function updateAllLists()
		{
			updateBrowser();
			updatePlaylist();
			updateSearch();
		}


		function setAndPlayTrack(track)
		{
			gebi('trackName').innerHTML='&nbsp;'+getTrackTitle(track)+'<br>&nbsp;<smallPath>'+getTrackDir(track)+'</smallPath>';
			if (<?php echo (TRACK_AS_TITLE?'true':'false'); ?>)
			{
				document.title=getTrackTitle(track);
			}
			errorHandling=false;
			playingTrack=track;
			player.currentTime=0;
			player.src=track;
			player.play();
			updateAllLists();
		}


		function getTrackTitle(track)
		{
			var name=track.split('/').pop();
			name=name.replace(new RegExp('_','g'),' ');
			name=name.substr(0,name.lastIndexOf('.'));
			return name;
		}


		function getTrackDir(track)
		{
			track='<?php echo TXT_ROOT; ?>/'+track.replace(new RegExp('_','g'),' ');
			var dirStr=track.split('/');
			var tmp=dirStr.pop();
			return dirStr.join('<?php echo ICON_ARROW; ?>');
		}


		function updateBrowser()
		{
			var list='';
			list+='<div class="listContainer overflowAuto"><div class="browserPath paddingTop" onClick="browseDir()">&nbsp;<?php echo TXT_ROOT; ?>&nbsp;</div>';
			for(var i=0;i<browserCurDirs.length;i++)
			{
				list+='<div class="browserPath paddingTop" onClick="browseDirFromBreadCrumbBar('+i+')">&nbsp;'+browserCurDirs[i]+'&nbsp;</div>';
			}
			list+='</div>';
			for(var i=0;i<browserDirs.length;i++)
			{
				list+='<div class="listContainer"><div class="browserDir overflowAuto" onClick="browseDir('+i+')">&nbsp;'+browserDirs[i]+'&nbsp;<br>&nbsp;<smallPath>'+getTrackDir(browserCurDir)+'</smallPath></div></div>';
			}
			var playlistCount;
			for(var i=0;i<browserTitles.length;i++)
			{
				playlistCount=inPlaylist(browserCurDir+browserTitles[i]);
				list+='<div class="listContainer"><div class="'+(playingTrack==browserCurDir+browserTitles[i]?'browserTitleHL':'browserTitle')+' overflowAuto" onClick="setTrackFromBrowser('+i+',true)">&nbsp;'+getTrackTitle(browserTitles[i])+'&nbsp;<br>&nbsp;<smallPath>'+getTrackDir(browserCurDir)+'</smallPath></div><div class="browserAction" onClick="'+(playlistCount>0?'removeBrowserTrackFromPlaylist':'addTrackFromBrowser')+'('+i+')">'+(playlistCount>0?'<div class="mark"><?php echo ICON_MARK; ?></div>':'&nbsp;')+'</div></div>';
			}
			gebi('frameBrowser').innerHTML=list;
		}


		function updatePlaylist()
		{
			if(shuffle)
			{
				updateShuffledList();
			}
			savePlaylist();
			var list='<div class="listContainer">';
			if (playlistTracks.length>0)
			{
				list+='<div class="browserDir paddingTop" onClick="clearPlaylist()">&nbsp;<?php echo TXT_TRACKS; ?>: '+String(playlistTracks.length)+' <?php echo TXT_CLEAR; ?>';
			}
			else
			{
				list+='<div class="browserDir paddingTop">&nbsp;<?php echo TXT_EMPTY; ?>';
			}
			list+='</div></div>';
			for(var i=0;i<playlistTracks.length;i++)
			{
				list+='<div class="listContainer"><div class="'+(playingTrack==playlistTracks[i]?'browserTitleHL':'browserTitle')+' overflowAuto" onClick="setTrackFromPlaylist('+i+',true)">&nbsp;'+getTrackTitle(playlistTracks[i])+'&nbsp;<br>&nbsp;<smallPath>'+getTrackDir(playlistTracks[i])+'</smallPath></div><div class="browserAction" onClick="removeTrack('+i+')"><div class="mark"><?php echo ICON_MARK; ?></div></div></div>';
			}
			gebi('framePlaylist').innerHTML=list;
		}


		function updateSearch(action)
		{
			if(action!=undefined)
			{
				searchAction=action;
			}
			var list='<div class="listContainer"><div class="browserPath w48p txtCenter"><div class="txtVCenter"><input class="inp" value="'+(searchAction=='clear'?'':searchString)+'" id="searchStr" name="searchStr" type="text"></div></div><div class="browserPath w25p txtCenter paddingTop" onClick="searchString=gebi(\'searchStr\').value; searchForTitle(searchString); updateSearch(\'search\')"><?php echo TXT_TITLE; ?></div><div class="browserPath w25p txtCenter paddingTop" onClick="searchString=gebi(\'searchStr\').value; searchForDir(searchString); updateSearch(\'search\')"><?php echo TXT_DIR; ?></div></div>';
			list+='<div class="listContainer"><div class="browserDir paddingTop" onClick="updateSearch(\'clear\')">';
			if (searchAction=='dir')
			{
				list+='&nbsp;<?php echo TXT_DIR.' '.TXT_SEARCH_RES; ?>: '+String(searchDirs.length);
			}
			else if (searchAction=='title')
			{
				list+='&nbsp;<?php echo TXT_TITLE.' '.TXT_SEARCH_RES; ?>: '+String(searchDirTracks.length);
			}
			else if (searchAction=='search')
			{
				list+='&nbsp;<?php echo TXT_SEARCHING; ?>';
				searchDirs=[];
				searchDirTracks=[];
			}
			else if (searchAction=='clear')
			{
				list+='&nbsp;<?php echo TXT_SEARCH_DESC; ?>';
				searchDirs=[];
				searchDirTracks=[];
			}
			else
			{
				list+='&nbsp;<?php echo TXT_SEARCH_DESC; ?>';
			}
			list+='</div></div>';
			for(var i=0;i<searchDirs.length;i++)
			{
				list+='<div class="listContainer"><div class="browserDir overflowAuto" onClick="browseDirByStr(searchDirs['+i+'])">&nbsp;'+searchDirs[i].split('/').pop()+'&nbsp;<br>&nbsp;<smallPath>'+getTrackDir(searchDirs[i])+'</smallPath></div></div>';
			}
			var playlistCount;
			for(var i=0;i<searchDirTracks.length;i++)
			{
				playlistCount=inPlaylist(searchDirTracks[i]);
				list+='<div class="listContainer"><div class="'+(playingTrack==searchDirTracks[i]?'browserTitleHL':'browserTitle')+' overflowAuto" onClick="setTrackFromSearch('+i+',true)">&nbsp;'+getTrackTitle(searchDirTracks[i])+'&nbsp;<br>&nbsp;<smallPath>'+getTrackDir(searchDirTracks[i])+'</smallPath></div><div class="browserAction" onClick="'+(playlistCount>0?'removeSearchTrackFromPlaylist':'addTrackFromSearch')+'('+i+')">'+(playlistCount>0?'<div class="mark"><?php echo ICON_MARK; ?></div>':'&nbsp;')+'</div></div>';
			}
			gebi('frameSearch').innerHTML=list;
		}


		function inPlaylist(track)
		{
			var number=0;
			for(var i=0;i<playlistTracks.length;i++)
			{
				if(playlistTracks[i]==track)
				{
					number++;
				}
			}
			return number;	
		}


		function addTrackFromBrowser(id)
		{
			playlistTracks[playlistTracks.length]=browserCurDir+browserTitles[id];
			updateAllLists();
		}


		function addTrackFromSearch(id)
		{
			playlistTracks[playlistTracks.length]=searchDirTracks[id];
			updateAllLists();
		}


		function clearPlaylist()
		{
			if (confirm('Clear Playlist?')==true)
			{
				playlistTracks=[];
				updateAllLists();
			}
		}


		function playerPlayPause()
		{
			if (player.paused)
			{
				if (playingTrack=='') // if no track is chosen play first track from active tab
				{
					playing=0;
					if ( (tabShowing=='browser') && (browserTitles.length > 0) )
					{
						if (shuffle)
						{
							playing=Math.floor(Math.random()*browserPlaylistTitles.length);
						}
						setTrackFromBrowser(playing, true);
					}
					if ( (tabShowing=='playlist') && (playlistTracks.length > 0) )
					{
						if (shuffle)
						{
							playing=Math.floor(Math.random()*playlistTracks.length);
						}
						setTrackFromPlaylist(playing, true);
					}
					if ( (tabShowing=='search') && (searchDirTracks.length > 0) )
					{
						if (shuffle)
						{
							playing=Math.floor(Math.random()*searchplaylistTracks.length);
						}
						setTrackFromSearch(playing, true);
					}
				}
				else
				{
					player.play();
				}
			}
			else
			{
				player.pause();
			}
		}


		function playerStop(forceStop)
		{
			if(forceStop || ((player.paused)&&(player.currentTime==0)) || errorHandling)
			{
				player.src='';
				player.removeAttribute('src');
				errorHandling=false;
				gebi('trackName').innerHTML='';
				if (<?php echo (TRACK_AS_TITLE?'true':'false'); ?>)
				{
					document.title='<?php echo TXT_PLAYER_TITLE; ?>';
				}
				playing=0;
				updateProgressBar();
				markPlayingTab('');
				playingTrack='';
				gebi('buttonPlay').innerHTML='<?php echo ICON_PLAY; ?>';
			}
			else
			{
				player.pause();
				player.currentTime=0;
			}
			updateAllLists();
		}


		function removeBrowserTrackFromPlaylist(id)
		{
			var index=playlistTracks.lastIndexOf(browserCurDir+browserTitles[id])
			if(index>-1)
			{
				playlistTracks.splice(index,1);
			}
			updateAllLists();
		}


		function removeSearchTrackFromPlaylist(id)
		{
			var index=playlistTracks.lastIndexOf(searchDirTracks[id])
			if(index>-1)
			{
				playlistTracks.splice(index,1);
			}
			updateAllLists();
		}


		function removeTrack(id)
		{
			playlistTracks.splice(id,1);
			if ((playingFrom=='list') && (id<=playing))
			{
				playing--;
			}
			updateAllLists();
		}


		function searchForTitle(search)
		{
			markLoading('search');
			loadFromServer('searchTitle',search);
		}


		function searchForDir(search)
		{
			markLoading('search');
			loadFromServer('searchDir',search);
		}


		function browseDirFromBreadCrumbBar(id)
		{
			var dir='';
			for(var i=0;i<=id;i++)
			{
				dir+=browserCurDirs[i]+'/';
			}
			markLoading('browser');
			loadFromServer('dir',dir);
		}


		function browseDir(id)
		{
			var dir='';
			if(id!==undefined)
			{
				dir+=browserCurDir+browserDirs[id]+'/';
			}
			markLoading('browser');
			loadFromServer('dir',dir);
		}


		function browseDirByStr(str)
		{
			markLoading('browser');
			loadFromServer('dir',str+'/');
			tabShowing='';
			showTab('browser');
		}


		function loadNextTreeDirTracks(str)
		{
			markLoading('browser');
			loadFromServer('treePlay',str+'|'+(loop?'loopOn':'loopOff'));
		}


		function getPlayingDir()
		{
			if(playingTrack!=='')
			{
				var path=playingTrack.substr(0,playingTrack.lastIndexOf('/'))+'/';
				markLoading('browser');
				loadFromServer('dir',path);
				tabShowing='';
				showTab('browser');
			}
		}


		function loadFromServer(param,varia)
		{
			dataframeTime=<?php echo SERVER_TIMEOUT; ?>;
			loading=true;
			gebi('dffunc').value=param;
			gebi('dfdata').value=varia;
			gebi('dfform').submit();
		}


		function checkDataframe()
		{
			if(loading)
			{
				if(dataframeTime>0)
				{
					dataframeTime--;
				}
				else
				{
					loading=false;
					markLoading(false);
					window.frames['dataframe'].window.location.replace('about:blank');
					alert('<?php echo TXT_NO_RES; ?>');
				}
			}
			setTimeout(function () { checkDataframe(); }, 1000);
		}


		function showTab(id)
		{
			if(tabShowing==id)
			{
				if(id=='browser') // if browser tab is clicked while already active, use it as browse one level up
				{
					if(browserCurDirs.length>1)
					{
						browseDirFromBreadCrumbBar(browserCurDirs.length-2);
					}
					else if(browserCurDirs.length==1)
					{
						browseDir();
					}
				}
			}
			else
			{
				tabShowing=id;
				if (id=='browser')
				{
					gebi('frameBrowser').style.display='inline';
					gebi('framePlaylist').style.display='none';
					gebi('frameSearch').style.display='none';
					gebi('frameSettings').style.display='none';
					gebi('tabBrowser').style.background='var(--CLR_TAB_ACT)';
					gebi('tabPlaylist').style.background='var(--CLR_TAB)';
					gebi('tabSearch').style.background='var(--CLR_TAB)';
					gebi('tabSettings').style.background='var(--CLR_TAB)';
				}
				if (id=='playlist')
				{
					gebi('frameBrowser').style.display='none';
					gebi('framePlaylist').style.display='inline';
					gebi('frameSearch').style.display='none';
					gebi('frameSettings').style.display='none';
					gebi('tabBrowser').style.background='var(--CLR_TAB)';
					gebi('tabPlaylist').style.background='var(--CLR_TAB_ACT)';
					gebi('tabSearch').style.background='var(--CLR_TAB)';
					gebi('tabSettings').style.background='var(--CLR_TAB)';
				}
				if (id=='search')
				{
					gebi('frameBrowser').style.display='none';
					gebi('framePlaylist').style.display='none';
					gebi('frameSearch').style.display='inline';
					gebi('frameSettings').style.display='none';
					gebi('tabBrowser').style.background='var(--CLR_TAB)';
					gebi('tabPlaylist').style.background='var(--CLR_TAB)';
					gebi('tabSearch').style.background='var(--CLR_TAB_ACT)';
					gebi('tabSettings').style.background='var(--CLR_TAB)';
				}
				if (id=='settings')
				{
					gebi('frameBrowser').style.display='none';
					gebi('framePlaylist').style.display='none';
					gebi('frameSearch').style.display='none';
					gebi('frameSettings').style.display='inline';
					gebi('tabBrowser').style.background='var(--CLR_TAB)';
					gebi('tabPlaylist').style.background='var(--CLR_TAB)';
					gebi('tabSearch').style.background='var(--CLR_TAB)';
					gebi('tabSettings').style.background='var(--CLR_TAB_ACT)';
				}
			}
		}


		function themeGetDefault()
		{
			var theme=localStorage.getItem('theme');
			{
				if(theme==='dark')
				{
					return 'dark';
				}
				if(theme==='light')
				{
					return 'light';
				}
				return 'os'; // default
			}
		}


		function themeUpdate()
		{
			if(themeCurrent==='os')
			{
				gebi('themeToggle').innerHTML = '<?php echo ICON_OS_THEME; ?>'
				if (window.matchMedia('(prefers-color-scheme: light)').matches)
				{
					document.querySelector('html').setAttribute('data-theme', 'light');
					document.querySelector('meta[name="theme-color"]').setAttribute("content", "<?php echo CLR_LIGHT_BACK; ?>");
				}
				else
				{
					document.querySelector('html').setAttribute('data-theme', 'dark');
					document.querySelector('meta[name="theme-color"]').setAttribute("content", "<?php echo CLR_DARK_BACK; ?>");
				}
			
			}
			else if(themeCurrent==='light')
			{
				gebi('themeToggle').innerHTML = '<?php echo ICON_LIGHT_THEME; ?>'
				document.querySelector('html').setAttribute('data-theme', 'light');
				document.querySelector('meta[name="theme-color"]').setAttribute("content", "<?php echo CLR_LIGHT_BACK; ?>");
			}
			else
			{
				gebi('themeToggle').innerHTML = '<?php echo ICON_DARK_THEME; ?>'
				document.querySelector('html').setAttribute('data-theme', 'dark');
				document.querySelector('meta[name="theme-color"]').setAttribute("content", "<?php echo CLR_DARK_BACK; ?>");
			}
		}


		function themeToggle()
		{
			if(themeCurrent==='os')
			{
				themeCurrent='light';
			}
			else if(themeCurrent==='light')
			{
				themeCurrent='dark';
			}
			else
			{
				themeCurrent='os';
			}
			localStorage.setItem('theme', themeCurrent);
			themeUpdate();
		}

	</script>
</head>
<body onload="init()">
	<audio class="hideout" autoplay id="player" preload="auto" tabindex="0"></audio>
	<div class="hideout"><form id="dfform" target="dataframe" action="<?php echo $_SERVER['PHP_SELF']; ?>" method="post"><input type="hidden" name="dffunc" id="dffunc" value=""><input type="hidden" name="dfdata" id="dfdata" value=""></form><iframe src="about:blank" height="0" width="0" name="dataframe"></iframe></div>
	<div class="fixedMenu"><div class="timeBox" id="trackCurrentTime"></div><div class="timeBox" id="trackRemaining"></div><div class="timeBox" id="trackDuration"></div><div id="bar" class="bar"></div><div id="trackName" class="trackName" onClick="getPlayingDir()">&nbsp;</div><div class="button" onClick="playerPlayPause()" id="buttonPlay"><?php echo ICON_PLAY; ?></div><div class="button" onClick="playerStop()" id="buttonStop"><?php echo ICON_STOP; ?></div><div class="button" onClick="changeTrack(-1)"><?php echo ICON_PREVIOUS; ?></div><div class="button" onClick="changeTrack(1)"><?php echo ICON_NEXT; ?></div><div class="landscape"><div class="collectionLS"><?php echo skipButton(SKIP_BUTTONS_LANDSCAPE) ?></div></div></div>
	<div class="tabBack"><div class="tabBrowser" id="tabBrowser" onClick="showTab('browser')"><div id="markBrowser" class="markPlay"><?php echo ICON_PLAY; ?></div><div id="markLoadBrowser" class="markLoad"><?php echo ICON_LOAD; ?></div><div class="tabTextAlign"><?php echo TXT_BROWSER; ?></div></div><div class="tabPlaylist" id="tabPlaylist" onClick="showTab('playlist')"><div id="markList" class="markPlay"><?php echo ICON_PLAY; ?></div><div class="tabTextAlign"><?php echo TXT_PLAYLIST; ?></div></div><div class="tabSearch" id="tabSearch" onClick="showTab('search')"><div id="markSearch" class="markPlay"><?php echo ICON_PLAY; ?></div><div id="markLoadSearch" class="markLoad"><?php echo ICON_LOAD; ?></div><div class="tabTextAlign"><?php echo TXT_SEARCH; ?></div></div><div class="tabSettings" id="tabSettings" onClick="showTab('settings')"><div class="tabTextAlign"><?php echo ICON_SETTINGS; ?></div></div></div>
	<div class="tabFrameBack"></div>
	<div id="frameBrowser" class="tabFrame"></div>
	<div id="framePlaylist" class="tabFrame"></div>
	<div id="frameSearch" class="tabFrame"></div>
	<div id="frameSettings" class="tabFrame"><div class="collection"><?php echo skipButton(SKIP_BUTTONS_MENU) ?></div>
		<div class="collection cursorPointer" onClick="themeToggle()"><div id="themeToggle" class="buttonSmallOff">&nbsp;</div><div class="description"><?php echo TXT_THEME; ?></div></div>
		<div class="collection cursorPointer" onClick="shuffleToggle()"><div id="shuffle" class="buttonSmallOff"><?php echo ICON_SHUFFLE; ?></div><div class="description"><?php echo TXT_SHUFFLE; ?></div></div>
		<div class="collection cursorPointer" onClick="loopToggle()"><div id="loop" class="buttonSmallOff"><?php echo ICON_LOOP; ?></div><div class="description"><?php echo TXT_LOOP; ?></div></div>
		<div class="collection cursorPointer" onClick="treeToggle()"><div id="tree" class="buttonSmallOff"><?php echo ICON_TREE; ?></div><div class="description"><?php echo TXT_TREE; ?></div></div>
	</div>
</body>
</html>